# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import morai_mgeo_pb2 as morai__mgeo__pb2
import morai_type_pb2 as morai__type__pb2


class MoraiMgeoStub(object):
    """지도 관련 서비스
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetMGeo = channel.unary_unary(
                '/morai_sim_api.MoraiMgeo/GetMGeo',
                request_serializer=morai__mgeo__pb2.MapInfo.SerializeToString,
                response_deserializer=morai__mgeo__pb2.MGeoData.FromString,
                )
        self.GetLeftLink = channel.unary_unary(
                '/morai_sim_api.MoraiMgeo/GetLeftLink',
                request_serializer=morai__type__pb2.LinkInfo.SerializeToString,
                response_deserializer=morai__mgeo__pb2.GetLinkResponse.FromString,
                )
        self.GetRightLink = channel.unary_unary(
                '/morai_sim_api.MoraiMgeo/GetRightLink',
                request_serializer=morai__type__pb2.LinkInfo.SerializeToString,
                response_deserializer=morai__mgeo__pb2.GetLinkResponse.FromString,
                )
        self.GetToLinks = channel.unary_unary(
                '/morai_sim_api.MoraiMgeo/GetToLinks',
                request_serializer=morai__type__pb2.LinkInfo.SerializeToString,
                response_deserializer=morai__mgeo__pb2.GetLinkResponseList.FromString,
                )
        self.GetFromLinks = channel.unary_unary(
                '/morai_sim_api.MoraiMgeo/GetFromLinks',
                request_serializer=morai__type__pb2.LinkInfo.SerializeToString,
                response_deserializer=morai__mgeo__pb2.GetLinkResponseList.FromString,
                )
        self.GetVehiclesOnLink = channel.unary_unary(
                '/morai_sim_api.MoraiMgeo/GetVehiclesOnLink',
                request_serializer=morai__type__pb2.LinkInfo.SerializeToString,
                response_deserializer=morai__mgeo__pb2.GetVehiclesOnLinkResponseList.FromString,
                )


class MoraiMgeoServicer(object):
    """지도 관련 서비스
    """

    def GetMGeo(self, request, context):
        """// MGeo 데이터를 가져옴
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLeftLink(self, request, context):
        """// 왼쪽 링크를 가져옴
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRightLink(self, request, context):
        """// 오른쪽 링크를 가져옴
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetToLinks(self, request, context):
        """// To 링크들을 가져옴
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetFromLinks(self, request, context):
        """// From 링크들을 가져옴
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetVehiclesOnLink(self, request, context):
        """// 링크에 있는 차량 정보를 가져옴
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MoraiMgeoServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetMGeo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMGeo,
                    request_deserializer=morai__mgeo__pb2.MapInfo.FromString,
                    response_serializer=morai__mgeo__pb2.MGeoData.SerializeToString,
            ),
            'GetLeftLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLeftLink,
                    request_deserializer=morai__type__pb2.LinkInfo.FromString,
                    response_serializer=morai__mgeo__pb2.GetLinkResponse.SerializeToString,
            ),
            'GetRightLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRightLink,
                    request_deserializer=morai__type__pb2.LinkInfo.FromString,
                    response_serializer=morai__mgeo__pb2.GetLinkResponse.SerializeToString,
            ),
            'GetToLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetToLinks,
                    request_deserializer=morai__type__pb2.LinkInfo.FromString,
                    response_serializer=morai__mgeo__pb2.GetLinkResponseList.SerializeToString,
            ),
            'GetFromLinks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetFromLinks,
                    request_deserializer=morai__type__pb2.LinkInfo.FromString,
                    response_serializer=morai__mgeo__pb2.GetLinkResponseList.SerializeToString,
            ),
            'GetVehiclesOnLink': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVehiclesOnLink,
                    request_deserializer=morai__type__pb2.LinkInfo.FromString,
                    response_serializer=morai__mgeo__pb2.GetVehiclesOnLinkResponseList.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'morai_sim_api.MoraiMgeo', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MoraiMgeo(object):
    """지도 관련 서비스
    """

    @staticmethod
    def GetMGeo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiMgeo/GetMGeo',
            morai__mgeo__pb2.MapInfo.SerializeToString,
            morai__mgeo__pb2.MGeoData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLeftLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiMgeo/GetLeftLink',
            morai__type__pb2.LinkInfo.SerializeToString,
            morai__mgeo__pb2.GetLinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRightLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiMgeo/GetRightLink',
            morai__type__pb2.LinkInfo.SerializeToString,
            morai__mgeo__pb2.GetLinkResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetToLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiMgeo/GetToLinks',
            morai__type__pb2.LinkInfo.SerializeToString,
            morai__mgeo__pb2.GetLinkResponseList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetFromLinks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiMgeo/GetFromLinks',
            morai__type__pb2.LinkInfo.SerializeToString,
            morai__mgeo__pb2.GetLinkResponseList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetVehiclesOnLink(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiMgeo/GetVehiclesOnLink',
            morai__type__pb2.LinkInfo.SerializeToString,
            morai__mgeo__pb2.GetVehiclesOnLinkResponseList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import morai_simulation_pb2 as morai__simulation__pb2
import morai_type_pb2 as morai__type__pb2


class MoraiSimulationStub(object):
    """시뮬레이션 시 사용하는 서비스
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Initialize = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/Initialize',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.IsSynchronousMode = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/IsSynchronousMode',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.BoolValue.FromString,
                )
        self.SetSynchronousMode = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/SetSynchronousMode',
                request_serializer=morai__type__pb2.BoolValue.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.Tick = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/Tick',
                request_serializer=morai__type__pb2.Int32Value.SerializeToString,
                response_deserializer=morai__type__pb2.Uint64Value.FromString,
                )
        self.WaitForTick = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/WaitForTick',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.Int64Value.FromString,
                )
        self.GetEnviroTime = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/GetEnviroTime',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.Uint32Value.FromString,
                )
        self.SetEnviroTime = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/SetEnviroTime',
                request_serializer=morai__type__pb2.Uint32Value.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.Pause = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/Pause',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.Resume = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/Resume',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.SetWeather = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/SetWeather',
                request_serializer=morai__simulation__pb2.WeatherParam.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.GetWeather = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/GetWeather',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__simulation__pb2.WeatherParam.FromString,
                )
        self.LoadWorld = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/LoadWorld',
                request_serializer=morai__simulation__pb2.LoadWorldParam.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.LoadBuiltInScenario = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/LoadBuiltInScenario',
                request_serializer=morai__type__pb2.StringValue.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.LoadSensorConfig = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/LoadSensorConfig',
                request_serializer=morai__simulation__pb2.SensorConfig.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.GetCurrentMapName = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/GetCurrentMapName',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=morai__type__pb2.StringValue.FromString,
                )
        self.SetSimulatorTimeScale = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/SetSimulatorTimeScale',
                request_serializer=morai__type__pb2.FloatValue.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.RayCast = channel.unary_unary(
                '/morai_sim_api.MoraiSimulation/RayCast',
                request_serializer=morai__simulation__pb2.RaycastParam.SerializeToString,
                response_deserializer=morai__type__pb2.FloatValue.FromString,
                )


class MoraiSimulationServicer(object):
    """시뮬레이션 시 사용하는 서비스
    """

    def Initialize(self, request, context):
        """// 시뮬레이션 초기화
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsSynchronousMode(self, request, context):
        """// 동기 모드인지 확인
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSynchronousMode(self, request, context):
        """// 동기/비동기 모드 설정
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Tick(self, request, context):
        """// 동기 모드일 때 설정한 시간만큼 Tick 진행
        param 단위 : msec
        response : frame index
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WaitForTick(self, request, context):
        """// 비동기 모드일 때 사용하는 rpc로 다음 틱이 돌아오면 리턴
        response : timestamp (msec)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEnviroTime(self, request, context):
        """// 환경 시간 조회
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetEnviroTime(self, request, context):
        """// 환경 시간 설정
        param : hour(0~24)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Pause(self, request, context):
        """// 시뮬레이션 일시 정지
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Resume(self, request, context):
        """시뮬레이션 재개
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetWeather(self, request, context):
        """// 날씨 설정
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWeather(self, request, context):
        """// 현재 날씨 조회
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadWorld(self, request, context):
        """// 맵 로드
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadBuiltInScenario(self, request, context):
        """// Built-in 시나리오 로드
        Param : 로드할 시나리오 파일 이름
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadSensorConfig(self, request, context):
        """// Sensor 설정 로드
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCurrentMapName(self, request, context):
        """// 현재 맵 이름
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetSimulatorTimeScale(self, request, context):
        """// Time scale 설정
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RayCast(self, request, context):
        """// Raycast
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MoraiSimulationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Initialize': grpc.unary_unary_rpc_method_handler(
                    servicer.Initialize,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'IsSynchronousMode': grpc.unary_unary_rpc_method_handler(
                    servicer.IsSynchronousMode,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.BoolValue.SerializeToString,
            ),
            'SetSynchronousMode': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSynchronousMode,
                    request_deserializer=morai__type__pb2.BoolValue.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'Tick': grpc.unary_unary_rpc_method_handler(
                    servicer.Tick,
                    request_deserializer=morai__type__pb2.Int32Value.FromString,
                    response_serializer=morai__type__pb2.Uint64Value.SerializeToString,
            ),
            'WaitForTick': grpc.unary_unary_rpc_method_handler(
                    servicer.WaitForTick,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.Int64Value.SerializeToString,
            ),
            'GetEnviroTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEnviroTime,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.Uint32Value.SerializeToString,
            ),
            'SetEnviroTime': grpc.unary_unary_rpc_method_handler(
                    servicer.SetEnviroTime,
                    request_deserializer=morai__type__pb2.Uint32Value.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'Pause': grpc.unary_unary_rpc_method_handler(
                    servicer.Pause,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'Resume': grpc.unary_unary_rpc_method_handler(
                    servicer.Resume,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'SetWeather': grpc.unary_unary_rpc_method_handler(
                    servicer.SetWeather,
                    request_deserializer=morai__simulation__pb2.WeatherParam.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'GetWeather': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWeather,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__simulation__pb2.WeatherParam.SerializeToString,
            ),
            'LoadWorld': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadWorld,
                    request_deserializer=morai__simulation__pb2.LoadWorldParam.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'LoadBuiltInScenario': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadBuiltInScenario,
                    request_deserializer=morai__type__pb2.StringValue.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'LoadSensorConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadSensorConfig,
                    request_deserializer=morai__simulation__pb2.SensorConfig.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'GetCurrentMapName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCurrentMapName,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=morai__type__pb2.StringValue.SerializeToString,
            ),
            'SetSimulatorTimeScale': grpc.unary_unary_rpc_method_handler(
                    servicer.SetSimulatorTimeScale,
                    request_deserializer=morai__type__pb2.FloatValue.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'RayCast': grpc.unary_unary_rpc_method_handler(
                    servicer.RayCast,
                    request_deserializer=morai__simulation__pb2.RaycastParam.FromString,
                    response_serializer=morai__type__pb2.FloatValue.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'morai_sim_api.MoraiSimulation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MoraiSimulation(object):
    """시뮬레이션 시 사용하는 서비스
    """

    @staticmethod
    def Initialize(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/Initialize',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsSynchronousMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/IsSynchronousMode',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.BoolValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSynchronousMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/SetSynchronousMode',
            morai__type__pb2.BoolValue.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Tick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/Tick',
            morai__type__pb2.Int32Value.SerializeToString,
            morai__type__pb2.Uint64Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WaitForTick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/WaitForTick',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.Int64Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEnviroTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/GetEnviroTime',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.Uint32Value.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetEnviroTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/SetEnviroTime',
            morai__type__pb2.Uint32Value.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Pause(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/Pause',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Resume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/Resume',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetWeather(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/SetWeather',
            morai__simulation__pb2.WeatherParam.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWeather(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/GetWeather',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__simulation__pb2.WeatherParam.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadWorld(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/LoadWorld',
            morai__simulation__pb2.LoadWorldParam.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadBuiltInScenario(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/LoadBuiltInScenario',
            morai__type__pb2.StringValue.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadSensorConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/LoadSensorConfig',
            morai__simulation__pb2.SensorConfig.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCurrentMapName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/GetCurrentMapName',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            morai__type__pb2.StringValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetSimulatorTimeScale(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/SetSimulatorTimeScale',
            morai__type__pb2.FloatValue.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RayCast(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSimulation/RayCast',
            morai__simulation__pb2.RaycastParam.SerializeToString,
            morai__type__pb2.FloatValue.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import os, sys

current_path = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.normpath(os.path.join(current_path, './')))
sys.path.append(os.path.normpath(os.path.join(current_path, '../')))

import morai_actor_pb2
import morai_type_pb2
import morai_simulation_pb2
import moraikit.types

def ToLocationMsg(msg, vector):
    msg.x = vector.x
    msg.y = vector.y
    msg.z = vector.z


def ToRotationMsg(msg, rotation):
    msg.x = rotation.roll
    msg.y = rotation.pitch
    msg.z = rotation.yaw


def from_vector3_msg(msg):
    return moraikit.types.Vector3(msg.x, msg.y, msg.z)


def to_vector3_msg(msg, vector):
    msg.x = vector.x
    msg.y = vector.y
    msg.z = vector.z

def from_location_msg(msg):
    return moraikit.types.Location(msg.x, msg.y, msg.z)


def from_rotation_msg(msg):
    return moraikit.types.Rotation(msg.x, msg.y, msg.z)


def from_actor_state_msg(msg):
    actor_state = moraikit.types.ActorState()
    if msg != None:
        actor_state.actor_info.role_name = msg.actor_info.actor_id
        actor_state.actor_info.actor_type = msg.actor_info.actor_type
        actor_state.bounding_box = from_bounding_box_msg(msg.bounding_box)
        from_transform_msg(actor_state.transform, msg.transform)
        actor_state.velocity = from_vector3_msg(msg.velocity)
        actor_state.angular_velocity = from_vector3_msg(msg.angular_velocity)
        actor_state.acceleration = from_vector3_msg(msg.acceleration)
        actor_state.vehicle_state = from_vehicle_state_msg(msg.vehicle_state)

    return actor_state


def from_network_item_msg(msg):
    network_item = moraikit.types.NetworkItem()
    network_item.network_item_type = msg.type
    network_item.value = msg.value

    return network_item


def from_network_protocol_setting_msg(msg):
    protocol_setting = moraikit.types.NetworkProtocolSetting()
    if msg != None:
        protocol_setting.comm_type = msg.comm_type
        for setting in msg.items:
            protocol_item = moraikit.types.NetworkProtocolItem()
            protocol_item.pubsub_type = setting.protocol
            for item in setting.items:
                protocol_item.network_items.append(from_network_item_msg(item))
            protocol_setting.protocol_items.append(protocol_item)

    return protocol_setting


def from_bounding_box_msg(msg):
    bounding_box = moraikit.types.BoundingBox()
    bounding_box.extent = from_vector3_msg(msg.extent)
    bounding_box.location = from_vector3_msg(msg.location)
    bounding_box.rotation = from_vector3_msg(msg.rotation)

    return bounding_box


def from_vehicle_state_msg(msg):
    vehicle_state = moraikit.types.VehicleState()
    vehicle_state.throttle = msg.throttle
    vehicle_state.steer = msg.steer
    vehicle_state.brake = msg.brake
    vehicle_state.front_wheel_angle = msg.front_wheel_angle
    vehicle_state.gear_mode = msg.gear_mode
    vehicle_state.vehicle_aux_state = from_vehicle_aux_state_msg(msg.aux_state)

    return vehicle_state


def from_vehicle_aux_state_msg(msg):
    vehicle_aux_state = moraikit.types.VehicleAuxState()
    vehicle_aux_state.current_link_info = from_link_info_msg(msg.current_link_info)
    vehicle_aux_state.remaining_distance = msg.remaining_distance
    vehicle_aux_state.is_pass_dest_pos = msg.is_pass_des_pos
    vehicle_aux_state.tl_id = msg.tl_id
    vehicle_aux_state.tl_color = msg.tl_color
    vehicle_aux_state.is_collision = msg.is_collision

    return vehicle_aux_state


def from_link_info_msg(msg):
    link_info = moraikit.types.LinkInfo()
    link_info.unique_id = msg.unique_id
    link_info.waypoint_idx = msg.waypoint_idx

    return link_info


def to_link_info_msg(link_info):
    msg = morai_type_pb2.LinkInfo()
    msg.unique_id = link_info.unique_id
    msg.waypoint_idx = link_info.waypoint_idx

    return msg


def from_tl_info_msg(msg):
    tl_info = moraikit.types.TrafficLightInfo()
    if msg is not None :
        tl_info.success = msg.success
        tl_info.tl_id = msg.tl_id
        tl_info.tl_color = msg.tl_color

    return tl_info


def to_transform_msg(msg, transform):
    ToLocationMsg(msg.location, transform.location)
    ToRotationMsg(msg.rotation, transform.rotation)


def from_transform_msg(transform, msg):
    transform.location = from_location_msg(msg.location)
    transform.rotation = from_rotation_msg(msg.rotation)


def to_raycast_param_msg(source, target, max_dist):
    msg = morai_simulation_pb2.RaycastParam()
    ToLocationMsg(msg.source, source)
    ToLocationMsg(msg.target, target)
    msg.max_dist = max_dist

    return msg


def to_vehicle_ctrl_cmd_msg(role_name, vehicle_control):
    msg = morai_actor_pb2.VehicleCtrlCmd()
    msg.actor_id = role_name
    msg.long_cmd_type = 1
    msg.throttle = vehicle_control.throttle
    msg.steer = vehicle_control.steer
    msg.brake = vehicle_control.brake
    msg.velocity = 0
    msg.acceleration = 0

    return msg    


def to_actor_info_msg(actor_info):
    msg = morai_actor_pb2.ActorInfo()
    msg.actor_id = actor_info.role_name
    msg.actor_type = actor_info.actor_type

    return msg


def to_network_item_msg(network_item):
    msg = morai_actor_pb2.NetworkItem()
    msg.type = network_item.network_item_type
    msg.value = network_item.value

    return msg


def to_network_ip_setting_msg(ip_item):
    msg = morai_actor_pb2.NetworkIpSetting()
    msg.connect_type = ip_item.connect_type

    for item in ip_item.network_items:
        msg.items.append(to_network_item_msg(item))

    return msg


def to_network_protocol_item_msg(protocol_item):
    msg = morai_actor_pb2.NetworkProtocolItem()
    msg.protocol = protocol_item.pubsub_type

    for item in protocol_item.network_items:
        msg.items.append(to_network_item_msg(item))

    return msg


# def to_network_protocol_setting_msg(protocol_setting):
#     msg = morai_actor_pb2.NetworkProtocolSetting()
#     msg.comm_type = protocol_setting.comm_type
#     for protocol_item in protocol_setting.protocol_items:
#         msg.items.append(to_network_protocol_item_msg(protocol_item))

#     return msg


def to_network_config_msg(msg, setting):
    msg.enabled = setting.enabled    
    msg.actor_info.actor_id = setting.actor_info.role_name
    msg.actor_info.actor_type = setting.actor_info.actor_type
    msg.comm_type = setting.comm_type
    msg.frame_rate = setting.frame_rate

    for ip_item in setting.ip_settings:        
        msg.ip_settings.append(to_network_ip_setting_msg(ip_item))

    msg.protocol_settings.comm_type = setting.comm_type
    for protocol_item in setting.protocol_settings.protocol_items:
        msg.protocol_settings.items.append(to_network_protocol_item_msg(protocol_item))

def to_vehicle_event_control_msg(msg, vehicle_event_control):
    msg.option = vehicle_event_control.option
    msg.ctrl_mode = vehicle_event_control.ctrl_mode
    msg.gear = vehicle_event_control.gear
    msg.turn_signal = vehicle_event_control.turn_signal
    msg.emergency_signal = vehicle_event_control.emergency_signal
    msg.set_pause = vehicle_event_control.set_pause

def to_actor_property_msg(actor_property):
    msg = morai_actor_pb2.ActorProperty()
    msg.actor_info.actor_id = actor_property.actor_info.role_name
    msg.actor_info.actor_type = actor_property.actor_info.actor_type
    msg.type = actor_property.type
    if msg.type == moraikit.types.ActorPropertyType.ACTOR_PROPERTY_TRANSFORM:
        to_transform_msg(msg.transform, actor_property.transform)
    elif msg.type == moraikit.types.ActorPropertyType.ACTOR_PROPERTY_NETWORK:
        to_network_config_msg(msg.network, actor_property.network)
    elif msg.type == moraikit.types.ActorPropertyType.ACTOR_PROPERTY_PHYSICS:
        msg.physics = actor_property.physics
    elif msg.type == moraikit.types.ActorPropertyType.ACTOR_PROPERTY_AI:
        msg.ai = actor_property.ai
    elif msg.type == moraikit.types.ActorPropertyType.ACTOR_PROPERTY_VEHICLE_EVENT:
        to_vehicle_event_control_msg(msg.vehicle_event_control, actor_property.vehicle_event_control)

    return msg


def to_ego_ctrl_cmd(ego_ctrl_cmd):
    msg = morai_actor_pb2.EgoCtrlCmd()
    to_transform_msg(msg.transform, ego_ctrl_cmd.transform)
    msg.velocity = ego_ctrl_cmd.velocity
    msg.pause = ego_ctrl_cmd.pause
    to_ego_cruise_ctrl_msg(msg.cruise_settings, ego_ctrl_cmd.cruise_settings)

    return msg


def to_ego_cruise_ctrl_msg(msg, ego_cruise_ctrl):
    msg.cruise_on = ego_cruise_ctrl.cruise_on
    msg.cruise_type = ego_cruise_ctrl.cruise_type
    msg.link_speed_ratio = ego_cruise_ctrl.link_speed_ratio
    msg.constant_velocity = ego_cruise_ctrl.constant_velocity

    return msg


def to_vehicle_route_msg(vehicle_route):
    msg = morai_actor_pb2.VehicleRoute()
    msg.actor_info.actor_id = vehicle_route.actor_info.role_name
    msg.actor_info.actor_type = vehicle_route.actor_info.actor_type
    msg.vehicle_type = vehicle_route.vehicle_type
    msg.decision_range = vehicle_route.decision_range
    for link in vehicle_route.link_list:
        msg.links.append(to_link_info_msg(link))

    return msg

def to_vehicle_destination_msg(vehicle_destination):
    msg = morai_actor_pb2.VehicleDestination()
    msg.actor_info.actor_id = vehicle_destination.actor_info.role_name
    msg.actor_info.actor_type = vehicle_destination.actor_info.actor_type
    msg.vehicle_type = vehicle_destination.vehicle_type
    msg.decision_range = vehicle_destination.decision_range
    to_vector3_msg(msg.position, vehicle_destination.position)

    return msg
